==> just_agents-0.1.1.tar.gz: just_agents-0.1.1/setup.py <==
from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '0.1.1'
DESCRIPTION = 'Just Agents'
LONG_DESCRIPTION = 'LLM Agents that are implemented without unnecessary complexity'

# Setting up
setup(
    name="just-agents",
    version=VERSION,
    author="Alex Karmazin, Anton Kulaga",
    author_email="antonkulaga@gmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=["litellm>=1.48.7", "numpydoc", "requests", "typer>=0.12.5"],
    extras_require={
        'templates' :[
            # optional dependency for templating
            "Mako>=1.3.5"
        ],
        'tools': [
            # some default tools
            'semanticscholar>=0.8.4'
        ]
    },
    keywords=['python', 'llm', 'science', 'review', 'agents', 'AI'],
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    package_data={
        'just_agents': ['config/agent_prompts.yaml'],
    },
    include_package_data=True,
)

==> just_agents-0.2.4.tar.gz: just_agents-0.2.4/setup.py <==
from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '0.2.4'
DESCRIPTION = 'Just Agents'
LONG_DESCRIPTION = 'LLM Agents that are implemented without unnecessary complexity'

# Setting up
setup(
    name="just-agents",
    version=VERSION,
    author="Alex Karmazin",
    author_email="karmazinalex@gmail.com",
    maintainer="Anton Kulaga",
    maintainer_email="antonkulaga@gmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=["litellm>=1.51.0", "numpydoc", "requests", "typer>=0.12.5"],
    extras_require={
        'tools': [
            'semanticscholar>=0.8.4'
        ],
        'coding': [
            'llm-sandbox>=0.1.2'
        ]
    },
    keywords=['python', 'llm', 'science', 'review', 'agents', 'AI'],
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    package_data={
        'just_agents': ['config/*.yaml'],
        'just_agents_coding': ['config/*.yaml'],
        
    },
    include_package_data=True,
)
